@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::Validate;
 
-our $DATE = '2016-06-02'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $DATE = '2016-07-22'; # DATE
+our $VERSION = '0.23'; # VERSION
 
 use 5.010001;
 use strict;
@@ -52,6 +52,12 @@ sub munge_file {
     my ($self, $file) = @_;
 
     my $fname = $file->name;
+
+    unless ($file->isa("Dist::Zilla::File::OnDisk")) {
+        $self->log_debug(["skipping %s: not an ondisk file, currently only ondisk files are processed", $fname]);
+        return;
+    }
+
     $self->log_debug("Processing file $fname ...");
 
     unless ($fname =~ m!lib/(.+\.pm)$!) {
@@ -346,7 +352,7 @@ Dist::Zilla::Plugin::Rinci::Validate - Insert argument validator code in output
 
 =head1 VERSION
 
-This document describes version 0.22 of Dist::Zilla::Plugin::Rinci::Validate (from Perl distribution Dist-Zilla-Plugin-Rinci-Validate), released on 2016-06-02.
+This document describes version 0.23 of Dist::Zilla::Plugin::Rinci::Validate (from Perl distribution Dist-Zilla-Plugin-Rinci-Validate), released on 2016-07-22.
 
 =head1 SYNOPSIS
 
